"""This module contains a dummy middleware for djangoldp testing."""

class DummyMiddleware(object):
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        return self.get_response(request)
